==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/LaunchTemplateCpuOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LaunchTemplateCpuOptionsRequest(
    coreCount: Optional[Integer] = Optional.Absent,
    threadsPerCore: Optional[Integer] = Optional.Absent,
    amdSevSnp: Optional[zio.aws.ec2.model.AmdSevSnpSpecification] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest = {
    import LaunchTemplateCpuOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest
      .builder()
      .optionallyWith(coreCount.map(value => value: java.lang.Integer))(
        _.coreCount
      )
      .optionallyWith(threadsPerCore.map(value => value: java.lang.Integer))(
        _.threadsPerCore
      )
      .optionallyWith(amdSevSnp.map(value => value.unwrap))(_.amdSevSnp)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest.ReadOnly =
    zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest.wrap(buildAwsValue())
}
object LaunchTemplateCpuOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest =
      zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest(
        coreCount.map(value => value),
        threadsPerCore.map(value => value),
        amdSevSnp.map(value => value)
      )
    def coreCount: Optional[Integer]
    def threadsPerCore: Optional[Integer]
    def amdSevSnp: Optional[zio.aws.ec2.model.AmdSevSnpSpecification]
    def getCoreCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("coreCount", coreCount)
    def getThreadsPerCore: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("threadsPerCore", threadsPerCore)
    def getAmdSevSnp
        : ZIO[Any, AwsError, zio.aws.ec2.model.AmdSevSnpSpecification] =
      AwsError.unwrapOptionField("amdSevSnp", amdSevSnp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest
  ) extends zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest.ReadOnly {
    override val coreCount: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.coreCount())
      .map(value => value: Integer)
    override val threadsPerCore: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.threadsPerCore())
      .map(value => value: Integer)
    override val amdSevSnp: Optional[zio.aws.ec2.model.AmdSevSnpSpecification] =
      zio.aws.core.internal
        .optionalFromNullable(impl.amdSevSnp())
        .map(value => zio.aws.ec2.model.AmdSevSnpSpecification.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest
  ): zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.17.124.3-sources.jar: zio/aws/ec2/model/LaunchTemplateCpuOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LaunchTemplateCpuOptionsRequest(
    coreCount: Option[Integer] = None,
    threadsPerCore: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest = {
    import LaunchTemplateCpuOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest
      .builder()
      .optionallyWith(
        coreCount.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.coreCount)
      .optionallyWith(
        threadsPerCore.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.threadsPerCore)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest.ReadOnly =
    zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest.wrap(buildAwsValue())
}
object LaunchTemplateCpuOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest =
      zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest(
        coreCount.map(value => value),
        threadsPerCore.map(value => value)
      )
    def coreCount: Option[Integer]
    def threadsPerCore: Option[Integer]
    def getCoreCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("coreCount", coreCount)
    def getThreadsPerCore: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("threadsPerCore", threadsPerCore)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest
  ) extends zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest.ReadOnly {
    override val coreCount: Option[Integer] = scala
      .Option(impl.coreCount())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val threadsPerCore: Option[Integer] = scala
      .Option(impl.threadsPerCore())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateCpuOptionsRequest
  ): zio.aws.ec2.model.LaunchTemplateCpuOptionsRequest.ReadOnly = new Wrapper(
    impl
  )
}
